"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const commands_1 = require("@seagull/commands");
const libraries_1 = require("@seagull/libraries");
const mock_cloudwatchlogs_1 = require("@seagull/mock-cloudwatchlogs");
const AWS = require("aws-sdk");
const moment = require("moment");
const logging_sandbox_1 = require("./logging_sandbox");
class CreateStream extends commands_1.Command {
    constructor(params) {
        super();
        this.CWL = new AWS.CloudWatchLogs({
            credentials: AWS.config.credentials,
            region: 'eu-central-1',
        });
        this.executeCloud = this.exec.bind(this, this.CWL);
        this.executePure = this.exec.bind(this, logging_sandbox_1.CWLSandbox);
        this.executeConnected = this.executeCloud;
        this.executeEdge = this.exec.bind(this, new mock_cloudwatchlogs_1.CWLMockFS('/tmp/.data'));
        this.logGroupName = `/${libraries_1.getAppName()}/data-log`;
        this.logStreamName = createStreamName(params.logStreamName);
    }
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.executeHandler();
        });
    }
    revert() {
        return __awaiter(this, void 0, void 0, function* () {
            return undefined;
        });
    }
    exec(client) {
        return __awaiter(this, void 0, void 0, function* () {
            yield client
                .createLogStream({
                logGroupName: this.logGroupName,
                logStreamName: this.logStreamName,
            })
                .promise();
            return this.logStreamName;
        });
    }
}
exports.CreateStream = CreateStream;
function createStreamName(customName) {
    const hash = Math.random()
        .toString(36)
        .substring(7);
    const time = moment.utc();
    return `${customName}-${time.format()}-${hash}`.replace(/(\*)|(:)/g, '-');
}
//# sourceMappingURL=create_stream.js.map