"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const commands_1 = require("@seagull/commands");
const libraries_1 = require("@seagull/libraries");
const mock_cloudwatchlogs_1 = require("@seagull/mock-cloudwatchlogs");
const AWS = require("aws-sdk");
const logging_sandbox_1 = require("./logging_sandbox");
class ReadLog extends commands_1.Command {
    constructor(params) {
        super();
        this.CWL = new AWS.CloudWatchLogs({
            credentials: AWS.config.credentials,
            region: 'eu-central-1',
        });
        this.executeCloud = this.exec.bind(this, this.CWL);
        this.executePure = this.exec.bind(this, logging_sandbox_1.CWLSandbox);
        this.executeConnected = this.executeCloud;
        this.executeEdge = this.exec.bind(this, new mock_cloudwatchlogs_1.CWLMockFS('/tmp/.data'));
        const groupName = {
            logGroupName: params.logGroupName || `/${libraries_1.getAppName()}/data-log`,
        };
        this.params = Object.assign(Object.assign({}, params), groupName);
    }
    execute() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.executeHandler();
        });
    }
    revert() {
        return __awaiter(this, void 0, void 0, function* () {
            return undefined;
        });
    }
    getOriginalLog() {
        if (this.result) {
            const events = this.result.events;
            const original = events.map(event => {
                const arr = event.message.split(' ');
                arr.shift();
                return JSON.parse(arr.join(' '));
            });
            return original;
        }
        else {
            throw new Error('no data, execute ReadLog first');
        }
    }
    getOriginalLogWithTimestamps() {
        if (this.result) {
            const events = this.result.events;
            const original = events.map(event => {
                const arr = event.message.split(' ');
                arr.shift();
                return {
                    message: JSON.parse(arr.join(' ')),
                    timestamp: event.timestamp,
                };
            });
            return original;
        }
        else {
            throw new Error('no data, execute ReadLog first');
        }
    }
    exec(client) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield client.getLogEvents(this.params).promise();
            this.result = result;
            return result;
        });
    }
}
exports.ReadLog = ReadLog;
//# sourceMappingURL=read_log.js.map